[llvm-commits] CVS: llvm/include/llvm/Target/TargetMachineImpls.h

Brian Gaeke gaeke at cs.uiuc.edu
Wed Feb 25 13:10:15 PST 2004


Changes in directory llvm/include/llvm/Target:

TargetMachineImpls.h updated: 1.10 -> 1.11

---
Log message:

Great renaming part II: Sparc --> SparcV9 (also includes command-line options and Makefiles)

---
Diffs of the changes:  (+2 -2)

Index: llvm/include/llvm/Target/TargetMachineImpls.h
diff -u llvm/include/llvm/Target/TargetMachineImpls.h:1.10 llvm/include/llvm/Target/TargetMachineImpls.h:1.11
--- llvm/include/llvm/Target/TargetMachineImpls.h:1.10	Fri Feb 13 17:36:03 2004
+++ llvm/include/llvm/Target/TargetMachineImpls.h	Wed Feb 25 13:08:11 2004
@@ -29,12 +29,12 @@
   TargetMachine *allocateCTargetMachine(const Module &M,
                                         IntrinsicLowering *IL = 0);
 
   // allocateSparcTargetMachine - Allocate and return a subclass of
   // TargetMachine that implements the Sparc backend.  This takes ownership of
   // the IntrinsicLowering pointer, deleting it when the target machine is
   // destroyed.
   //
-  TargetMachine *allocateSparcTargetMachine(const Module &M,
+  TargetMachine *allocateSparcV9TargetMachine(const Module &M,
                                             IntrinsicLowering *IL = 0);
   
   // allocateX86TargetMachine - Allocate and return a subclass of TargetMachine
@@ -29,12 +29,12 @@
                                         IntrinsicLowering *IL = 0);
 
-  // allocateSparcTargetMachine - Allocate and return a subclass of
+  // allocateSparcV9TargetMachine - Allocate and return a subclass of
   // TargetMachine that implements the Sparc backend.  This takes ownership of
   // the IntrinsicLowering pointer, deleting it when the target machine is





More information about the llvm-commits mailing list